library(glmmTMB)
library(car)



dol_yearly = read.table("Dol Soc by Env Yearly data PPB.txt", header = T) 
dol_yearly$yearf = factor(dol_yearly$year)
dol_yearly$sexf = factor(dol_yearly$sex)
dol_yearly$dummy = 1


dol_monthly = read.table("Dol Soc by Env Monthly data PPB.txt", header = T) 
dol_monthly$yearf = factor(dol_monthly$year)
dol_monthly$sexf = factor(dol_monthly$sex)
dol_monthly$dummy = 1



#Yearly Models####

#Str - NAO

dol_str_ynao_m1 = glmmTMB((indiv_str+0.001) ~ 
                            scale(year_nao) * sexf + 
                            (scale(year_nao)|dol_name) + 
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "log"),
                          data = dol_yearly) 

summary(dol_str_ynao_m1)
Anova(dol_str_ynao_m1 , type="III") 

dol_str_ynao_m2 = glmmTMB((indiv_str+0.001) ~ 
                            scale(year_nao) * sexf + 
                            (scale(year_nao)||dol_name) + #suppress correlation
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "log"),
                          data = dol_yearly) 

anova(dol_str_ynao_m1 ,dol_str_ynao_m2)

dol_str_ynao_m3 = glmmTMB((indiv_str+0.001) ~ 
                            scale(year_nao) * sexf + 
                            (1|dol_name) + #no random slopes
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "log"),
                          data = dol_yearly) 
#Chi-squared:
2*(logLik(dol_str_ynao_m2) - logLik(dol_str_ynao_m3))

#p value:
0.5*pchisq(2*(logLik(dol_str_ynao_m2) - logLik(dol_str_ynao_m3)), 
           1, lower.tail = FALSE) 

#Conditional repeatability [need code from Schielzeth, H. & Nakagawa, S. (2022). 
#'Conditional repeatability and the variance explained by reaction norm variation in random slope models' 
#Methods in Ecology and Evolution
#https://github.com/hschielzeth/RandomSlopeR2/blob/master/condR.R                    

source("condR code from S & N 2022.R")

str_ynao = condR(betaX = summary(dol_str_ynao_m1)$coef$cond[2,1],
            meanX = 0,
            Vx = 1,
            Vr = sigma(dol_str_ynao_m1)^2,
            Sigma = matrix(VarCorr(dol_str_ynao_m1)[[1]]$dol_name[1:4],2,2),
            Vo = VarCorr(dol_str_ynao_m1)[[1]]$dummy[1],
            xrange=c(-2,2))

#Clustering coefficient - NAO

dol_cc_ynao_m1 = glmmTMB(indiv_cc ~ 
                           scale(year_nao) * sexf + 
                           (scale(year_nao)|dol_name) + 
                           ar1(yearf + 0 | dummy), 
                         family=gaussian(link = "logit"), 
                         data = dol_yearly, 
                         control=glmmTMBControl(optimizer=optim,
                                                optArgs=list(method="BFGS"))) 
summary(dol_cc_ynao_m1) 
Anova(dol_cc_ynao_m1 , type="III") 

dol_cc_ynao_m2 = glmmTMB(indiv_cc ~ 
                           scale(year_nao) * sexf + 
                           (scale(year_nao)||dol_name) + 
                           ar1(yearf + 0 | dummy), 
                         family=gaussian(link = "logit"), 
                         data = dol_yearly, 
                         control=glmmTMBControl(optimizer=optim,
                                              optArgs=list(method="BFGS"))) 
anova(dol_cc_ynao_m1 ,dol_cc_ynao_m2) 

dol_cc_ynao_m3 = glmmTMB(indiv_cc ~ 
                           scale(year_nao) * sexf + 
                           (1|dol_name) + 
                           ar1(yearf + 0 | dummy), 
                         family=gaussian(link = "logit"), 
                         data = dol_yearly, 
                         control=glmmTMBControl(optimizer=optim,
                                                optArgs=list(method="BFGS"))) 

2*(logLik(dol_cc_ynao_m2) - logLik(dol_cc_ynao_m3))
0.5*pchisq(2*(logLik(dol_cc_ynao_m2) - logLik(dol_cc_ynao_m3)), 
           1, lower.tail = FALSE) 

condR(betaX = summary(dol_cc_ynao_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_cc_ynao_m1)^2,
      Sigma = matrix(VarCorr(dol_cc_ynao_m1)[[1]]$dol_name[1:4],2,2),
      Vo = VarCorr(dol_cc_ynao_m1)[[1]]$dummy[1],
      xrange=c(-2,2))

#Closeness - NAO

dol_close_ynao_m1 = glmmTMB(indiv_close ~ 
                              scale(year_nao) *sexf +
                              (scale(year_nao)|dol_name) + 
                              ar1(yearf + 0 | dummy), 
                            family=gaussian(link = "log"), 
                            data = dol_yearly, 
                            control=glmmTMBControl(optimizer=optim,
                                                   optArgs=list(method="BFGS"))) 

summary(dol_close_ynao_m1) 
Anova(dol_close_ynao_m1 , type="III")

dol_close_ynao_m2 = glmmTMB(indiv_close ~ 
                              scale(year_nao) *sexf +
                              (scale(year_nao)||dol_name) + 
                              ar1(yearf + 0 | dummy), 
                            family=gaussian(link = "log"), 
                            data = dol_yearly, 
                            control=glmmTMBControl(optimizer=optim,
                                                   optArgs=list(method="BFGS"))) 
anova(dol_close_ynao_m1 ,dol_close_ynao_m2) 

#Clear difference so we don't remove it to test random slopes

condR(betaX = summary(dol_close_ynao_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_close_ynao_m1)^2,
      Sigma = matrix(VarCorr(dol_close_ynao_m1)[[1]]$dol_name[1:4],2,2),
      Vo = VarCorr(dol_close_ynao_m1)[[1]]$dummy[1],
      xrange=c(-2,2))

#Strengh - Salmon

dol_str_yfish_m1 = glmmTMB((indiv_str+0.001) ~ 
                             scale(year_fish) * sexf + 
                             (scale(year_fish)|dol_name) + 
                             ar1(yearf + 0 | dummy), 
                           family=gaussian(link = "log"),
                           data = dol_yearly) 

summary(dol_str_yfish_m1)
Anova(dol_str_yfish_m1 , type="III")

dol_str_yfish_m2 = glmmTMB((indiv_str+0.001) ~ 
                             scale(year_fish) * sexf + 
                             (scale(year_fish)||dol_name) + 
                             ar1(yearf + 0 | dummy), 
                           family=gaussian(link = "log"),
                           data = dol_yearly) 

anova(dol_str_yfish_m1 ,dol_str_yfish_m2)

#Clear difference so we don't remove it to test random slopes

condR(betaX = summary(dol_str_yfish_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_str_yfish_m1)^2,
      Sigma = matrix(VarCorr(dol_str_yfish_m1)[[1]]$dol_name[1:4],2,2),
      Vo = VarCorr(dol_str_yfish_m1)[[1]]$dummy[1],
      xrange=c(-2,2))

#Clustering coefficient - Salmon

dol_cc_yfish_m1 = glmmTMB(indiv_cc ~ 
                            scale(year_fish) * sexf +
                            (scale(year_fish)|dol_name) + 
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "logit"), 
                          data = dol_yearly, 
                          control=glmmTMBControl(optimizer=optim,
                                                 optArgs=list(method="BFGS"))) 

summary(dol_cc_yfish_m1)
Anova(dol_cc_yfish_m1 , type="III")

dol_cc_yfish_m2 = glmmTMB(indiv_cc ~ 
                            scale(year_fish) * sexf +
                            (scale(year_fish)||dol_name) + 
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "logit"), 
                          data = dol_yearly, 
                          control=glmmTMBControl(optimizer=optim,
                                                 optArgs=list(method="BFGS"))) 
anova(dol_cc_yfish_m1 ,dol_cc_yfish_m2)

dol_cc_yfish_m3 = glmmTMB(indiv_cc ~ 
                            scale(year_fish) * sexf +
                            (1|dol_name) + 
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "logit"), 
                          data = dol_yearly)

2*(logLik(dol_cc_yfish_m2) - logLik(dol_cc_yfish_m3))
0.5*pchisq(2*(logLik(dol_cc_yfish_m2) - logLik(dol_cc_yfish_m3)), 
           1, lower.tail = FALSE)

condR(betaX = summary(dol_cc_yfish_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_cc_yfish_m1)^2,
      Sigma = matrix(VarCorr(dol_cc_yfish_m1)[[1]]$dol_name[1:4],2,2),
      Vo = VarCorr(dol_cc_yfish_m1)[[1]]$dummy[1],
      xrange=c(-2,2))

#Closeness - Salmon

dol_close_yfish_m1 = glmmTMB(indiv_close ~ 
                               scale(year_fish) *sexf + 
                               (scale(year_fish)|dol_name) + 
                               ar1(yearf + 0 | dummy), 
                             family=gaussian(link = "log"), 
                             data = dol_yearly, 
                             control=glmmTMBControl(optimizer=optim,
                                                    optArgs=list(method="BFGS"))) 
summary(dol_close_yfish_m1)
Anova(dol_close_yfish_m1 , type="III")

dol_close_yfish_m2 = glmmTMB(indiv_close ~ 
                               scale(year_fish) *sexf + 
                               (scale(year_fish)||dol_name) + 
                               ar1(yearf + 0 | dummy), 
                             family=gaussian(link = "log"), 
                             data = dol_yearly, 
                             control=glmmTMBControl(optimizer=optim,
                                                    optArgs=list(method="BFGS"))) 
anova(dol_close_yfish_m1 ,dol_close_yfish_m2)

#Clear difference so we don't remove it to test random slopes

condR(betaX = summary(dol_close_yfish_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_close_yfish_m1)^2,
      Sigma = matrix(VarCorr(dol_close_yfish_m1)[[1]]$dol_name[1:4],2,2),
      Vo = VarCorr(dol_close_yfish_m1)[[1]]$dummy[1],
      xrange=c(-2,2))

#Plots of predicted relationships

#These take a while as it makes a prediction for each individual dolphin and adds it to the graph
#For each dolphin the year is randomly chosen from the years that dolphin recorded social phenotypes in

par(mfrow=c(2,3), mar = c(5.1, 4.1, 4.1, 2.1))

with(dol_yearly, plot(indiv_str ~ year_nao, 
                        cex = 0.5, pch = 16, col = rgb(0, 0.6, 1, 0.5),
                        xlab = "NAO index", ylab = "Individual strength"))
text(x = -1, y = 15, "a.", cex = 2)

for (i in 1:length(unique(dol_yearly$dol_name))) {
  data = data.frame(dol_name = unique(dol_yearly$dol_name)[i],
                    year_nao = seq(from = min(dol_yearly$year_nao[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    to = max(dol_yearly$year_nao[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    length.out = 100),
                    sexf = dol_yearly$sexf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]][1],
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    dummy = 1)
  data$pred_str = predict(dol_str_ynao_m1, newdata = data, type = "response")
  lines(data$year_nao, data$pred_str, cex = 0.5, col = rgb(0, 0.6, 1, 0.5))
  
}

with(dol_yearly, plot(indiv_cc ~ year_nao, 
                        cex = 0.5, pch = 16, col = rgb(0, 0.6, 1, 0.5),
                        xlab = "NAO index", ylab = "Individual clustering coefficient"))
text(x = -1, y = 0.97, "b.", cex = 2)

for (i in 1:length(unique(dol_yearly$dol_name))) {
  data = data.frame(dol_name = unique(dol_yearly$dol_name)[i],
                    year_nao = seq(from = min(dol_yearly$year_nao[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    to = max(dol_yearly$year_nao[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    length.out = 100),
                    sexf = sample(dol_yearly$sexf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]], 1),
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    dummy = 1)
  data$pred_cc = predict(dol_cc_ynao_m1, newdata = data, type = "response")
  lines(data$year_nao, data$pred_cc, cex = 0.5, col = rgb(0, 0.6, 1, 0.5))
  
}

with(dol_yearly, plot(indiv_close ~ year_nao, 
                        cex = 0.5, pch = 16, col = rgb(0, 0.6, 1, 0.5),
                        xlab = "NAO index", ylab = "Individual closeness"))
text(x = -1, y = 0.55, "c.", cex = 2)

for (i in 1:length(unique(dol_yearly$dol_name))) {
  data = data.frame(dol_name = unique(dol_yearly$dol_name)[i],
                    year_nao = seq(from = min(dol_yearly$year_nao[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    to = max(dol_yearly$year_nao[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    length.out = 100),
                    sexf = sample(dol_yearly$sexf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]], 1),
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    dummy = 1)
  data$pred_close = predict(dol_close_ynao_m1, newdata = data, type = "response")
  lines(data$year_nao, data$pred_close, cex = 0.5, col = rgb(0, 0.6, 1, 0.5))
  
}

#Salmon

with(dol_yearly, plot(indiv_str ~ year_fish, 
                        cex = 0.5, pch = 16, col = rgb(1, 0.4, 0, 0.5),
                        xlab = "Salmon abundance", ylab = "Individual strength"))
text(x = 2000, y = 15, "d.", cex = 2)

for (i in 1:length(unique(dol_yearly$dol_name))) {
  data = data.frame(dol_name = unique(dol_yearly$dol_name)[i],
                    year_fish = seq(from = min(dol_yearly$year_fish[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    to = max(dol_yearly$year_fish[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    length.out = 100),
                    sexf = sample(dol_yearly$sexf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]], 1),
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    dummy = 1)
  data$pred_str = predict(dol_str_yfish_m1, newdata = data, type = "response")
  lines(data$year_fish, data$pred_str, cex = 0.5, col = rgb(1, 0.4, 0, 0.5))
  
}

with(dol_yearly, plot(indiv_cc ~ year_fish, 
                        cex = 0.5, pch = 16, col = rgb(1, 0.4, 0, 0.5),
                        xlab = "Salmon abundance", ylab = "Individual clustering coefficient"))
text(x = 2000, y = 0.94, "e.", cex = 2)

for (i in 1:length(unique(dol_yearly$dol_name))) {
  data = data.frame(dol_name = unique(dol_yearly$dol_name)[i],
                    year_fish = seq(from = min(dol_yearly$year_fish[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    to = max(dol_yearly$year_fish[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    length.out = 100),
                    sexf = sample(dol_yearly$sexf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]], 1),
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    dummy = 1)
  data$pred_cc = predict(dol_cc_yfish_m1, newdata = data, type = "response")
  lines(data$year_fish, data$pred_cc, cex = 0.5, col = rgb(1, 0.4, 0, 0.5))
  
}

with(dol_yearly, plot(indiv_close ~ year_fish, 
                        cex = 0.5, pch = 16, col = rgb(1, 0.4, 0, 0.5),
                        xlab = "Salmon abundance", ylab = "Individual closeness"))
text(x = 2000, y = 0.51, "f.", cex = 2)

for (i in 1:length(unique(dol_yearly$dol_name))) {
  data = data.frame(dol_name = unique(dol_yearly$dol_name)[i],
                    year_fish = seq(from = min(dol_yearly$year_fish[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    to = max(dol_yearly$year_fish[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]] ),
                                    length.out = 100),
                    sexf = sample(dol_yearly$sexf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]], 1),
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    dummy = 1)
  data$pred_close = predict(dol_close_yfish_m1, newdata = data, type = "response")
  lines(data$year_fish, data$pred_close, cex = 0.5, col = rgb(1, 0.4, 0, 0.5))
  
}

par(mfrow=c(1,1))

#Monthly models####

#Strength - NAO

dol_str_mnao_m1 = glmmTMB((indiv_str+0.001) ~  
                            scale(month_year_nao)  * sexf +
                            (scale(month_year_nao)|dol_name) +
                            (1|month) +
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "log"), 
                          data = dol_monthly, 
                          control=glmmTMBControl(optimizer=optim,
                                                 optArgs=list(method="BFGS"))) 
#works with BFGS
summary(dol_str_mnao_m1)
Anova(dol_str_mnao_m1 , type="III") 

dol_str_mnao_m2 = glmmTMB((indiv_str+0.001) ~  
                            scale(month_year_nao)  * sexf +
                            (scale(month_year_nao)||dol_name) +
                            (1|month) +
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "log"), 
                          data = dol_monthly, 
                          control=glmmTMBControl(optimizer=optim,
                                                 optArgs=list(method="BFGS"))) 

anova(dol_str_mnao_m1, dol_str_mnao_m2) #do not need the correlation

dol_str_mnao_m3 = glmmTMB((indiv_str+0.001) ~  
                            scale(month_year_nao)  * sexf +
                            (1|dol_name) +
                            (1|month) +
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "log"), 
                          data = dol_monthly, 
                          control=glmmTMBControl(optimizer=optim,
                                                 optArgs=list(method="BFGS"))) 

2*(logLik(dol_str_mnao_m2) - logLik(dol_str_mnao_m3)) 
0.5*pchisq(2*(logLik(dol_str_mnao_m2) - logLik(dol_str_mnao_m3)), 
           1, lower.tail = FALSE) 

condR(betaX = summary(dol_str_mnao_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_str_mnao_m1)^2,
      Sigma = matrix(VarCorr(dol_str_mnao_m1)[[1]]$dol_name[1:4],2,2),
      Vo = c(VarCorr(dol_str_mnao_m1)[[1]]$dummy[1], VarCorr(dol_str_mnao_m1)[[1]]$month.x[1]),
      xrange=c(-2,2))

#Clustering coefficient - NAO

dol_cc_mnao_m1 = glmmTMB(indiv_cc ~ 
                           scale(month_year_nao) * sexf + 
                           (scale(month_year_nao)|dol_name) + 
                           (1|month) +
                           ar1(yearf + 0 | dummy), 
                         family=gaussian(link = "logit"), 
                         data = dol_monthly) 
summary(dol_cc_mnao_m1)
Anova(dol_cc_mnao_m1 , type="III")

dol_cc_mnao_m2 = glmmTMB(indiv_cc ~ 
                           scale(month_year_nao) * sexf + 
                           (scale(month_year_nao)||dol_name) + 
                           (1|month) +
                           ar1(yearf + 0 | dummy), 
                         family=gaussian(link = "logit"), 
                         data = dol_monthly) 

anova(dol_cc_mnao_m1 ,dol_cc_mnao_m2)

dol_cc_mnao_m3 = glmmTMB(indiv_cc ~ 
                           scale(month_year_nao) * sexf + 
                           (1|dol_name) + 
                           (1|month) +
                           ar1(yearf + 0 | dummy), 
                         family=gaussian(link = "logit"), 
                         data = dol_monthly) 

2*(logLik(dol_cc_mnao_m2) - logLik(dol_cc_mnao_m3))
0.5*pchisq(2*(logLik(dol_cc_mnao_m2) - logLik(dol_cc_mnao_m3)), 
           1, lower.tail = FALSE)

condR(betaX = summary(dol_cc_mnao_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_cc_mnao_m1)^2,
      Sigma = matrix(VarCorr(dol_cc_mnao_m1)[[1]]$dol_name[1:4],2,2),
      Vo = c(VarCorr(dol_cc_mnao_m1)[[1]]$dummy[1], VarCorr(dol_cc_mnao_m1)[[1]]$month.x[1]), 
      xrange=c(-2,2))

#Closeness - NAO

dol_close_mnao_m1 = glmmTMB(indiv_close ~ 
                              scale(month_year_nao) *sexf + 
                              (scale(month_year_nao)|dol_name) + 
                              (1|month) +
                              ar1(yearf + 0 | dummy), 
                            family=gaussian(link = "log"), 
                            data = dol_monthly) 
summary(dol_close_mnao_m1)
Anova(dol_close_mnao_m1 , type="III") 

dol_close_mnao_m2 = glmmTMB(indiv_close ~ 
                              scale(month_year_nao) *sexf + 
                              (scale(month_year_nao)||dol_name) + 
                              (1|month) +
                              ar1(yearf + 0 | dummy), 
                            family=gaussian(link = "log"), 
                            data = dol_monthly) 
anova(dol_close_mnao_m1 ,dol_close_mnao_m2) #do not need correlation

dol_close_mnao_m3 = glmmTMB(indiv_close ~ 
                              scale(month_year_nao) *sexf + 
                              (1|dol_name) + 
                              (1|month) +
                              ar1(yearf + 0 | dummy), 
                            family=gaussian(link = "log"), 
                            data = dol_monthly) 
2*(logLik(dol_close_mnao_m2) - logLik(dol_close_mnao_m3)) 
0.5*pchisq(2*(logLik(dol_close_mnao_m2) - logLik(dol_close_mnao_m3)), 
           1, lower.tail = FALSE) 

condR(betaX = summary(dol_close_mnao_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_close_mnao_m1)^2,
      Sigma = matrix(VarCorr(dol_close_mnao_m1)[[1]]$dol_name[1:4],2,2),
      Vo = c(VarCorr(dol_close_mnao_m1)[[1]]$dummy[1],VarCorr(dol_close_mnao_m1)[[1]]$month.x[1]),
      xrange=c(-2,2))

#Strength - Salmon

dol_str_mfish_m1 = glmmTMB((indiv_str+0.001) ~  
                             scale(month_year_fish)  * sexf +  
                             (scale(month_year_fish)|dol_name) + 
                             (1|month) + 
                             ar1(yearf + 0 | dummy),
                           family=gaussian(link = "log"), 
                           data = dol_monthly) 
summary(dol_str_mfish_m1)
Anova(dol_str_mfish_m1 , type="III")

dol_str_mfish_m2 = glmmTMB((indiv_str+0.001) ~  
                             scale(month_year_fish)  * sexf +  
                             (scale(month_year_fish)||dol_name) + 
                             (1|month) + 
                             ar1(yearf + 0 | dummy),
                           family=gaussian(link = "log"), 
                           data = dol_monthly) 
anova(dol_str_mfish_m1, dol_str_mfish_m2) 

condR(betaX = summary(dol_str_mfish_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_str_mfish_m1)^2,
      Sigma = matrix(VarCorr(dol_str_mfish_m1)[[1]]$dol_name[1:4],2,2),
      Vo = c(VarCorr(dol_str_mfish_m1)[[1]]$dummy[1], VarCorr(dol_str_mfish_m1)[[1]]$month.x[1]),
      xrange=c(-2,2))

#Clustering coefficient - Salmon

dol_cc_mfish_m1 = glmmTMB(indiv_cc ~ 
                            scale(month_year_fish) * sexf + 
                            (scale(month_year_fish)|dol_name) + 
                            (1|month) +
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "logit"), 
                          data = dol_monthly, 
                          control=glmmTMBControl(optimizer=optim,
                                                 optArgs=list(method="BFGS"))) 
summary(dol_cc_mfish_m1)
Anova(dol_cc_mfish_m1 , type="III") 

dol_cc_mfish_m2 = glmmTMB(indiv_cc ~ 
                            scale(month_year_fish) * sexf + 
                            (scale(month_year_fish)||dol_name) + 
                            (1|month) +
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "logit"), 
                          data = dol_monthly, 
                          control=glmmTMBControl(optimizer=optim,
                                                 optArgs=list(method="BFGS")))
#This does not converge with or without BFGS
anova(dol_cc_mfish_m1 ,dol_cc_mfish_m2) #This does not produce a result as m2 does not converge

dol_cc_mfish_m3 = glmmTMB(indiv_cc ~ 
                            scale(month_year_fish) * sexf + 
                            (1|dol_name) + 
                            (1|month) +
                            ar1(yearf + 0 | dummy), 
                          family=gaussian(link = "logit"), 
                          data = dol_monthly, 
                          control=glmmTMBControl(optimizer=optim,
                                                 optArgs=list(method="BFGS")))
anova(dol_cc_mfish_m1 ,dol_cc_mfish_m3) #So we compare m1 (intercepts and slopes) against m3 (neither)


condR(betaX = summary(dol_cc_mfish_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_cc_mfish_m1)^2,
      Sigma = matrix(VarCorr(dol_cc_mfish_m1)[[1]]$dol_name[1:4],2,2),
      Vo = c(VarCorr(dol_cc_mfish_m1)[[1]]$dummy[1],VarCorr(dol_cc_mfish_m1)[[1]]$month.x[1]),
      xrange=c(-2,2))

#Closeness - Salmon

dol_close_mfish_m1 = glmmTMB(indiv_close ~ 
                               scale(month_year_fish) *sexf + 
                               (scale(month_year_fish)|dol_name) + 
                               (1|month) +
                               ar1(yearf + 0 | dummy), 
                             family=gaussian(link = "log"), 
                             data = dol_monthly, 
                             control=glmmTMBControl(optimizer=optim,
                                                    optArgs=list(method="BFGS"))) 
summary(dol_close_mfish_m1)
Anova(dol_close_mfish_m1 , type="III")

dol_close_mfish_m2 = glmmTMB(indiv_close ~ 
                               scale(month_year_fish) *sexf + 
                               (scale(month_year_fish)||dol_name) + 
                               (1|month) +
                               ar1(yearf + 0 | dummy), 
                             family=gaussian(link = "log"), 
                             data = dol_monthly, 
                             control=glmmTMBControl(optimizer=optim,
                                                    optArgs=list(method="BFGS"))) 
anova(dol_close_mfish_m1 ,dol_close_mfish_m2) #do not need correlation

dol_close_mfish_m3 = glmmTMB(indiv_close ~ 
                               scale(month_year_fish) *sexf + 
                               (1|dol_name) + 
                               (1|month) +
                               ar1(yearf + 0 | dummy), 
                             family=gaussian(link = "log"), 
                             data = dol_monthly, 
                             control=glmmTMBControl(optimizer=optim,
                                                    optArgs=list(method="BFGS"))) 
2*(logLik(dol_close_mfish_m2) - logLik(dol_close_mfish_m3))
0.5*pchisq(2*(logLik(dol_close_mfish_m2) - logLik(dol_close_mfish_m3)), 
           1, lower.tail = FALSE) 

condR(betaX = summary(dol_close_mfish_m1)$coef$cond[2,1],
      meanX = 0,
      Vx = 1,
      Vr = sigma(dol_close_mfish_m1)^2,
      Sigma = matrix(VarCorr(dol_close_mfish_m1)[[1]]$dol_name[1:4],2,2),
      Vo = c(VarCorr(dol_close_mfish_m1)[[1]]$dummy[1],VarCorr(dol_close_mfish_m1)[[1]]$month.x[1]),
      xrange=c(-2,2))

#Plots of predicted relationships####

#Choice of June (month = 6) is arbitrary

par(mfrow=c(2,3), mar = c(5.1, 4.1, 4.1, 2.1))

with(dol_monthly, plot(indiv_str ~ month_year_nao, 
                           cex = 0.5, pch = 16, col = rgb(0, 0.6, 1, 0.5),
                           xlab = "NAO index", ylab = "Individual strength"))
text(x = -3, y = 15, "a.", cex = 2)

for (i in 1:length(unique(dol_monthly$dol_name))) {
  data = data.frame(dol_name = unique(dol_monthly$dol_name)[i],
                    month_year_nao = seq(from = min(dol_monthly$month_year_nao[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                    to = max(dol_monthly$month_year_nao[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                    length.out = 100),
                    sexf = dol_monthly$sexf[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]][1],
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    month = 6, dummy = 1)
  data$pred_str = predict(dol_str_mnao_m1, newdata = data, type = "response")
  lines(data$month_year_nao, data$pred_str, cex = 0.5, col = rgb(0, 0.6, 1, 0.5))
  
}

with(dol_monthly, plot(indiv_cc ~ month_year_nao, 
                           cex = 0.5, pch = 16, col = rgb(0, 0.6, 1, 0.5),
                           xlab = "NAO index", ylab = "Individual clustering coefficient"))
text(x = -3, y = 0.95, "b.", cex = 2)

for (i in 1:length(unique(dol_monthly$dol_name))) {
  data = data.frame(dol_name = unique(dol_monthly$dol_name)[i],
                    month_year_nao = seq(from = min(dol_monthly$month_year_nao[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                    to = max(dol_monthly$month_year_nao[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                    length.out = 100),
                    sexf = dol_monthly$sexf[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]][1],
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    month = 6, dummy = 1)
  data$pred_cc = predict(dol_cc_mnao_m1, newdata = data, type = "response")
  lines(data$month_year_nao, data$pred_cc, cex = 0.5, col = rgb(0, 0.6, 1, 0.5))
  
}

with(dol_monthly, plot(indiv_close ~ month_year_nao, 
                           cex = 0.5, pch = 16, col = rgb(0, 0.6, 1, 0.5),
                           xlab = "NAO index", ylab = "Individual closeness"))
text(x = -3, y = 0.28, "c.", cex = 2)

for (i in 1:length(unique(dol_monthly$dol_name))) {
  data = data.frame(dol_name = unique(dol_monthly$dol_name)[i],
                    month_year_nao = seq(from = min(dol_monthly$month_year_nao[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                    to = max(dol_monthly$month_year_nao[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                    length.out = 100),
                    sexf = dol_monthly$sexf[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]][1],
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    month = 6, dummy = 1)
  data$pred_close = predict(dol_close_mnao_m1, newdata = data, type = "response")
  lines(data$month_year_nao, data$pred_close, cex = 0.5, col = rgb(0, 0.6, 1, 0.5))
  
}



#Salmon

with(dol_monthly, plot(indiv_str ~ month_year_fish, 
                           cex = 0.5, pch = 16, col = rgb(1, 0.4, 0, 0.5),
                           xlab = "Salmon abundance", ylab = "Individual strength"))
text(x = 130, y = 15, "d.", cex = 2)

for (i in 1:length(unique(dol_monthly$dol_name))) {
  data = data.frame(dol_name = unique(dol_monthly$dol_name)[i],
                    month_year_fish = seq(from = min(dol_monthly$month_year_fish[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                          to = max(dol_monthly$month_year_fish[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                          length.out = 100),
                    sexf = dol_monthly$sexf[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]][1],
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    month = 6, dummy = 1)
  data$pred_str = predict(dol_str_mfish_m1, newdata = data, type = "response")
  lines(data$month_year_fish, data$pred_str, cex = 0.5, col = rgb(1, 0.4, 0, 0.5))
  
}

with(dol_monthly, plot(indiv_cc ~ month_year_fish, 
                           cex = 0.5, pch = 16, col = rgb(1, 0.4, 0, 0.5),
                           xlab = "Salmon abundance", ylab = "Individual clustering coefficient"))
text(x = 130, y = 0.95, "e.", cex = 2)

for (i in 1:length(unique(dol_monthly$dol_name))) {
  data = data.frame(dol_name = unique(dol_monthly$dol_name)[i],
                    month_year_fish = seq(from = min(dol_monthly$month_year_fish[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                          to = max(dol_monthly$month_year_fish[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                          length.out = 100),
                    sexf = dol_monthly$sexf[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]][1],
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    month = 6, dummy = 1)
  data$pred_cc = predict(dol_cc_mfish_m1, newdata = data, type = "response")
  lines(data$month_year_fish, data$pred_cc, cex = 0.5, col = rgb(1, 0.4, 0, 0.5))
  
}

with(dol_monthly, plot(indiv_close ~ month_year_fish, 
                           cex = 0.5, pch = 16, col = rgb(1, 0.4, 0, 0.5),
                           xlab = "Salmon abundance", ylab = "Individual closeness"))
text(x = 130, y = 0.28, "f.", cex = 2)

for (i in 1:length(unique(dol_monthly$dol_name))) {
  data = data.frame(dol_name = unique(dol_monthly$dol_name)[i],
                    month_year_fish = seq(from = min(dol_monthly$month_year_fish[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                          to = max(dol_monthly$month_year_fish[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]] ),
                                          length.out = 100),
                    sexf = dol_monthly$sexf[dol_monthly$dol_name == unique(dol_monthly$dol_name)[i]][1],
                    yearf = sample(dol_yearly$yearf[dol_yearly$dol_name == unique(dol_yearly$dol_name)[i]],1), 
                    month = 6, dummy = 1)
  data$pred_close = predict(dol_close_mfish_m1, newdata = data, type = "response")
  lines(data$month_year_fish, data$pred_close, cex = 0.5, col = rgb(1, 0.4, 0, 0.5))
  
}

par(mfrow=c(1,1))



#END####